slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPCISSGetThreshold

Gets the values of various threshold parameters in the CISS solver.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPCISSGetThreshold(PEP pep,PetscReal *delta,PetscReal *spur)

Not Collective

### Input Parameter

| pep | - the polynomial eigensolver context

### Output Parameters

| delta | - threshold for numerical rank
| spur | - spurious threshold (to discard spurious eigenpairs)

### See Also

PEPCISSSetThreshold()

### Level

advanced

### Location

src/pep/impls/ciss/pciss.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages